@@ -1,16 +1,16 @@
 /* This file is part of Clementine.
    Copyright 2012, David Sansome <me@davidsansome.com>
-   
+
    Clementine is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    Clementine is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with Clementine.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -18,24 +18,24 @@
 #include "globalsearch.h"
 #include "globalsearchmodel.h"
 #include "core/mimedata.h"
+#include "ui/iconloader.h"
 
 #include <QSortFilterProxyModel>
 
 GlobalSearchModel::GlobalSearchModel(GlobalSearch* engine, QObject* parent)
-  : QStandardItemModel(parent),
-    engine_(engine),
-    proxy_(NULL),
-    use_pretty_covers_(true),
-    artist_icon_(":/icons/22x22/x-clementine-artist.png"),
-    album_icon_(":/icons/22x22/x-clementine-album.png")
-{
+    : QStandardItemModel(parent),
+      engine_(engine),
+      proxy_(nullptr),
+      use_pretty_covers_(true),
+      artist_icon_(IconLoader::Load("x-clementine-artist", IconLoader::Base)),
+      album_icon_(IconLoader::Load("x-clementine-album", IconLoader::Base)) {
   group_by_[0] = LibraryModel::GroupBy_Artist;
   group_by_[1] = LibraryModel::GroupBy_Album;
   group_by_[2] = LibraryModel::GroupBy_None;
 
   no_cover_icon_ = QPixmap(":nocover.png").scaled(
-        LibraryModel::kPrettyCoverSize, LibraryModel::kPrettyCoverSize,
-        Qt::KeepAspectRatio, Qt::SmoothTransformation);
+      LibraryModel::kPrettyCoverSize, LibraryModel::kPrettyCoverSize,
+      Qt::KeepAspectRatio, Qt::SmoothTransformation);
 }
 
 void GlobalSearchModel::AddResults(const SearchProvider::ResultList& results) {
@@ -50,10 +50,11 @@ void GlobalSearchModel::AddResults(const SearchProvider::ResultList& results) {
     if (configured_index != -1) {
       sort_index = configured_index;
     } else {
-      sort_index = next_provider_sort_index_ ++;
+      sort_index = next_provider_sort_index_++;
     }
 
-    QStandardItem* divider = new QStandardItem(provider->icon(), provider->name());
+    QStandardItem* divider =
+        new QStandardItem(provider->icon(), provider->name());
     divider->setData(true, LibraryModel::Role_IsDivider);
     divider->setData(sort_index, Role_ProviderIndex);
     divider->setFlags(Qt::ItemIsEnabled);
@@ -64,7 +65,7 @@ void GlobalSearchModel::AddResults(const SearchProvider::ResultList& results) {
     sort_index = provider_sort_indices_[provider];
   }
 
-  foreach (const SearchProvider::Result& result, results) {
+  for (const SearchProvider::Result& result : results) {
     QStandardItem* parent = invisibleRootItem();
 
     // Find (or create) the container nodes for this result if we can.
@@ -85,8 +86,10 @@ void GlobalSearchModel::AddResults(const SearchProvider::ResultList& results) {
   }
 }
 
-QStandardItem* GlobalSearchModel::BuildContainers(
-    const Song& s, QStandardItem* parent, ContainerKey* key, int level) {
+QStandardItem* GlobalSearchModel::BuildContainers(const Song& s,
+                                                  QStandardItem* parent,
+                                                  ContainerKey* key,
+                                                  int level) {
   if (level >= 3) {
     return parent;
   }
@@ -99,54 +102,80 @@ QStandardItem* GlobalSearchModel::BuildContainers(
   int year = 0;
 
   switch (group_by_[level]) {
-  case LibraryModel::GroupBy_Artist:
-    if (s.is_compilation()) {
-      display_text = tr("Various artists");
-      sort_text = "aaaaaa";
-    } else {
-      display_text = LibraryModel::TextOrUnknown(s.artist());
-      sort_text = LibraryModel::SortTextForArtist(s.artist());
-    }
-    has_artist_icon = true;
-    break;
+    case LibraryModel::GroupBy_Artist:
+      if (s.is_compilation()) {
+        display_text = tr("Various artists");
+        sort_text = "aaaaaa";
+      } else {
+        display_text = LibraryModel::TextOrUnknown(s.artist());
+        sort_text = LibraryModel::SortTextForArtist(s.artist());
+      }
+      has_artist_icon = true;
+      break;
 
-  case LibraryModel::GroupBy_YearAlbum:
-    year = qMax(0, s.year());
-    display_text = LibraryModel::PrettyYearAlbum(year, s.album());
-    sort_text = LibraryModel::SortTextForYear(year) + s.album();
-    unique_tag = s.album_id();
-    has_album_icon = true;
-    break;
+    case LibraryModel::GroupBy_YearAlbum:
+      year = qMax(0, s.year());
+      display_text = LibraryModel::PrettyYearAlbum(year, s.album());
+      sort_text = LibraryModel::SortTextForNumber(year) + s.album();
+      unique_tag = s.album_id();
+      has_album_icon = true;
+      break;
 
-  case LibraryModel::GroupBy_Year:
-    year = qMax(0, s.year());
-    display_text = QString::number(year);
-    sort_text = LibraryModel::SortTextForYear(year) + " ";
-    break;
+    case LibraryModel::GroupBy_OriginalYearAlbum:
+      year = qMax(0, s.effective_originalyear());
+      display_text = LibraryModel::PrettyYearAlbum(year, s.album());
+      sort_text = LibraryModel::SortTextForNumber(year) + s.album();
+      unique_tag = s.album_id();
+      has_album_icon = true;
+      break;
 
-  case LibraryModel::GroupBy_Composer:                         display_text = s.composer();
-  case LibraryModel::GroupBy_Performer:                        display_text = s.performer();
-  case LibraryModel::GroupBy_Grouping:                         display_text = s.grouping();
-  case LibraryModel::GroupBy_Genre: if (display_text.isNull()) display_text = s.genre();
-  case LibraryModel::GroupBy_Album:
-    unique_tag = s.album_id();
-    if (display_text.isNull()) {
-      display_text = s.album();
-    }
+    case LibraryModel::GroupBy_Year:
+      year = qMax(0, s.year());
+      display_text = QString::number(year);
+      sort_text = LibraryModel::SortTextForNumber(year) + " ";
+      break;
+
+    case LibraryModel::GroupBy_OriginalYear:
+      year = qMax(0, s.effective_originalyear());
+      display_text = QString::number(year);
+      sort_text = LibraryModel::SortTextForNumber(year) + " ";
+      break;
+
+    case LibraryModel::GroupBy_Composer:
+      display_text = s.composer();
+    case LibraryModel::GroupBy_Performer:
+      display_text = s.performer();
+    case LibraryModel::GroupBy_Disc:
+      display_text = s.disc();
+    case LibraryModel::GroupBy_Grouping:
+      display_text = s.grouping();
+    case LibraryModel::GroupBy_Genre:
+      if (display_text.isNull()) display_text = s.genre();
+    case LibraryModel::GroupBy_Album:
+      unique_tag = s.album_id();
+      if (display_text.isNull()) {
+        display_text = s.album();
+      }
     // fallthrough
-  case LibraryModel::GroupBy_AlbumArtist: if (display_text.isNull()) display_text = s.effective_albumartist();
-    display_text = LibraryModel::TextOrUnknown(display_text);
-    sort_text = LibraryModel::SortTextForArtist(display_text);
-    has_album_icon = true;
-    break;
+    case LibraryModel::GroupBy_AlbumArtist:
+      if (display_text.isNull()) display_text = s.effective_albumartist();
+      display_text = LibraryModel::TextOrUnknown(display_text);
+      sort_text = LibraryModel::SortTextForArtist(display_text);
+      has_album_icon = true;
+      break;
 
-  case LibraryModel::GroupBy_FileType:
-    display_text = s.TextForFiletype();
-    sort_text = display_text;
-    break;
+    case LibraryModel::GroupBy_FileType:
+      display_text = s.TextForFiletype();
+      sort_text = display_text;
+      break;
 
-  case LibraryModel::GroupBy_None:
-    return parent;
+    case LibraryModel::GroupBy_Bitrate:
+      display_text = QString(s.bitrate(), 1);
+      sort_text = display_text;
+      break;
+
+    case LibraryModel::GroupBy_None:
+      return parent;
   }
 
   // Find a container for this level
@@ -186,7 +215,7 @@ void GlobalSearchModel::Clear() {
 SearchProvider::ResultList GlobalSearchModel::GetChildResults(
     const QModelIndexList& indexes) const {
   QList<QStandardItem*> items;
-  foreach (const QModelIndex& index, indexes) {
+  for (const QModelIndex& index : indexes) {
     items << itemFromIndex(index);
   }
   return GetChildResults(items);
@@ -197,16 +226,16 @@ SearchProvider::ResultList GlobalSearchModel::GetChildResults(
   SearchProvider::ResultList results;
   QSet<const QStandardItem*> visited;
 
-  foreach (QStandardItem* item, items) {
+  for (QStandardItem* item : items) {
     GetChildResults(item, &results, &visited);
   }
 
   return results;
 }
 
-void GlobalSearchModel::GetChildResults(const QStandardItem* item,
-                                        SearchProvider::ResultList* results,
-                                        QSet<const QStandardItem*>* visited) const {
+void GlobalSearchModel::GetChildResults(
+    const QStandardItem* item, SearchProvider::ResultList* results,
+    QSet<const QStandardItem*>* visited) const {
   if (visited->contains(item)) {
     return;
   }
@@ -218,14 +247,35 @@ void GlobalSearchModel::GetChildResults(const QStandardItem* item,
 
     // Yes - visit all the children, but do so through the proxy so we get them
     // in the right order.
-    for (int i=0 ; i<item->rowCount() ; ++i) {
+    for (int i = 0; i < item->rowCount(); ++i) {
       const QModelIndex proxy_index = parent_proxy_index.child(i, 0);
       const QModelIndex index = proxy_->mapToSource(proxy_index);
       GetChildResults(itemFromIndex(index), results, visited);
     }
   } else {
-    // No - it's a song, add its result
-    results->append(item->data(Role_Result).value<SearchProvider::Result>());
+    // No - maybe it's a song, add its result if valid
+    QVariant result = item->data(Role_Result);
+    if (result.isValid()) {
+      results->append(result.value<SearchProvider::Result>());
+    } else {
+      // Maybe it's a provider then?
+      bool is_provider;
+      const int sort_index = item->data(Role_ProviderIndex).toInt(&is_provider);
+      if (is_provider) {
+        // Go through all the items (through the proxy to keep them ordered) and
+        // add the ones belonging to this provider to our list
+        for (int i = 0; i < proxy_->rowCount(invisibleRootItem()->index());
+             ++i) {
+          QModelIndex child_index =
+              proxy_->index(i, 0, invisibleRootItem()->index());
+          const QStandardItem* child_item =
+              itemFromIndex(proxy_->mapToSource(child_index));
+          if (child_item->data(Role_ProviderIndex).toInt() == sort_index) {
+            GetChildResults(child_item, results, visited);
+          }
+        }
+      }
+    }
   }
 }
 
@@ -238,11 +288,12 @@ void GatherResults(const QStandardItem* parent,
                    QMap<SearchProvider*, SearchProvider::ResultList>* results) {
   QVariant result_variant = parent->data(GlobalSearchModel::Role_Result);
   if (result_variant.isValid()) {
-    SearchProvider::Result result = result_variant.value<SearchProvider::Result>();
+    SearchProvider::Result result =
+        result_variant.value<SearchProvider::Result>();
     (*results)[result.provider_].append(result);
   }
 
-  for (int i=0 ; i<parent->rowCount() ; ++i) {
+  for (int i = 0; i < parent->rowCount(); ++i) {
     GatherResults(parent->child(i), results);
   }
 }
@@ -261,7 +312,7 @@ void GlobalSearchModel::SetGroupBy(const LibraryModel::Grouping& grouping,
     // Reset the model and re-add all the results using the new grouping.
     Clear();
 
-    foreach (const SearchProvider::ResultList& result_list, results) {
+    for (const SearchProvider::ResultList& result_list : results) {
       AddResults(result_list);
     }
   }
