@@ -23,26 +23,22 @@
 const char* TranscoderOptionsFlac::kSettingsGroup = "Transcoder/flacenc";
 
 TranscoderOptionsFlac::TranscoderOptionsFlac(QWidget* parent)
-  : TranscoderOptionsInterface(parent),
-    ui_(new Ui_TranscoderOptionsFlac)
-{
+    : TranscoderOptionsInterface(parent), ui_(new Ui_TranscoderOptionsFlac) {
   ui_->setupUi(this);
 }
 
-TranscoderOptionsFlac::~TranscoderOptionsFlac() {
-  delete ui_;
-}
+TranscoderOptionsFlac::~TranscoderOptionsFlac() { delete ui_; }
 
 void TranscoderOptionsFlac::Load() {
   QSettings s;
-  s.beginGroup(kSettingsGroup);
+  s.beginGroup(kSettingsGroup + settings_postfix_);
 
   ui_->quality->setValue(s.value("quality", 5).toInt());
 }
 
 void TranscoderOptionsFlac::Save() {
   QSettings s;
-  s.beginGroup(kSettingsGroup);
+  s.beginGroup(kSettingsGroup + settings_postfix_);
 
   s.setValue("quality", ui_->quality->value());
 }
