@@ -57,43 +57,46 @@ AlbumCoverManager::AlbumCoverManager(Application* app,
                                      LibraryBackend* library_backend,
                                      QWidget* parent,
                                      QNetworkAccessManager* network)
-  : QMainWindow(parent),
-    ui_(new Ui_CoverManager),
-    app_(app),
-    album_cover_choice_controller_(new AlbumCoverChoiceController(this)),
-    cover_fetcher_(new AlbumCoverFetcher(app_->cover_providers(), this, network)),
-    cover_searcher_(NULL),
-    cover_export_(NULL),
-    cover_exporter_(new AlbumCoverExporter(this)),
-    artist_icon_(IconLoader::Load("x-clementine-artist")),
-    all_artists_icon_(IconLoader::Load("x-clementine-album")),
-    context_menu_(new QMenu(this)),
-    progress_bar_(new QProgressBar(this)),
-    abort_progress_(new QPushButton(this)),
-    jobs_(0),
-    library_backend_(library_backend)
-{
+    : QMainWindow(parent),
+      ui_(new Ui_CoverManager),
+      app_(app),
+      album_cover_choice_controller_(new AlbumCoverChoiceController(this)),
+      cover_fetcher_(
+          new AlbumCoverFetcher(app_->cover_providers(), this, network)),
+      cover_searcher_(nullptr),
+      cover_export_(nullptr),
+      cover_exporter_(new AlbumCoverExporter(this)),
+      artist_icon_(IconLoader::Load("x-clementine-artist", IconLoader::Base)),
+      all_artists_icon_(IconLoader::Load("x-clementine-album", IconLoader::Base)),
+      context_menu_(new QMenu(this)),
+      progress_bar_(new QProgressBar(this)),
+      abort_progress_(new QPushButton(this)),
+      jobs_(0),
+      library_backend_(library_backend) {
   ui_->setupUi(this);
   ui_->albums->set_cover_manager(this);
 
   // Icons
-  ui_->action_fetch->setIcon(IconLoader::Load("download"));
-  ui_->export_covers->setIcon(IconLoader::Load("document-save"));
-  ui_->view->setIcon(IconLoader::Load("view-choose"));
-  ui_->fetch->setIcon(IconLoader::Load("download"));
-  ui_->action_add_to_playlist->setIcon(IconLoader::Load("media-playback-start"));
-  ui_->action_load->setIcon(IconLoader::Load("media-playback-start"));
+  ui_->action_fetch->setIcon(IconLoader::Load("download", IconLoader::Base));
+  ui_->export_covers->setIcon(IconLoader::Load("document-save", IconLoader::Base));
+  ui_->view->setIcon(IconLoader::Load("view-choose", IconLoader::Base));
+  ui_->fetch->setIcon(IconLoader::Load("download", IconLoader::Base));
+  ui_->action_add_to_playlist->setIcon(
+      IconLoader::Load("media-playback-start", IconLoader::Base));
+  ui_->action_load->setIcon(IconLoader::Load("media-playback-start", IconLoader::Base));
 
   album_cover_choice_controller_->SetApplication(app_);
 
   // Get a square version of nocover.png
   QImage nocover(":/nocover.png");
-  nocover = nocover.scaled(120, 120, Qt::KeepAspectRatio, Qt::SmoothTransformation);
+  nocover =
+      nocover.scaled(120, 120, Qt::KeepAspectRatio, Qt::SmoothTransformation);
   QImage square_nocover(120, 120, QImage::Format_ARGB32);
   square_nocover.fill(0);
   QPainter p(&square_nocover);
   p.setOpacity(0.4);
-  p.drawImage((120 - nocover.width()) / 2, (120 - nocover.height()) / 2, nocover);
+  p.drawImage((120 - nocover.width()) / 2, (120 - nocover.height()) / 2,
+              nocover);
   p.end();
   no_cover_icon_ = QPixmap::fromImage(square_nocover);
 
@@ -123,9 +126,7 @@ AlbumCoverManager::~AlbumCoverManager() {
   delete ui_;
 }
 
-LibraryBackend* AlbumCoverManager::backend() const {
-  return library_backend_;
-}
+LibraryBackend* AlbumCoverManager::backend() const { return library_backend_; }
 
 void AlbumCoverManager::Init() {
   // View menu
@@ -172,19 +173,24 @@ void AlbumCoverManager::Init() {
   ui_->albums->installEventFilter(this);
 
   // Connections
-  connect(ui_->artists, SIGNAL(currentItemChanged(QListWidgetItem*,QListWidgetItem*)),
+  connect(ui_->artists,
+          SIGNAL(currentItemChanged(QListWidgetItem*, QListWidgetItem*)),
           SLOT(ArtistChanged(QListWidgetItem*)));
   connect(ui_->filter, SIGNAL(textChanged(QString)), SLOT(UpdateFilter()));
   connect(filter_group, SIGNAL(triggered(QAction*)), SLOT(UpdateFilter()));
   connect(ui_->view, SIGNAL(clicked()), ui_->view, SLOT(showMenu()));
   connect(ui_->fetch, SIGNAL(clicked()), SLOT(FetchAlbumCovers()));
   connect(ui_->export_covers, SIGNAL(clicked()), SLOT(ExportCovers()));
-  connect(cover_fetcher_, SIGNAL(AlbumCoverFetched(quint64,QImage,CoverSearchStatistics)),
-          SLOT(AlbumCoverFetched(quint64,QImage,CoverSearchStatistics)));
+  connect(cover_fetcher_,
+          SIGNAL(AlbumCoverFetched(quint64, QImage, CoverSearchStatistics)),
+          SLOT(AlbumCoverFetched(quint64, QImage, CoverSearchStatistics)));
   connect(ui_->action_fetch, SIGNAL(triggered()), SLOT(FetchSingleCover()));
-  connect(ui_->albums, SIGNAL(doubleClicked(QModelIndex)), SLOT(AlbumDoubleClicked(QModelIndex)));
-  connect(ui_->action_add_to_playlist, SIGNAL(triggered()), SLOT(AddSelectedToPlaylist()));
-  connect(ui_->action_load, SIGNAL(triggered()), SLOT(LoadSelectedToPlaylist()));
+  connect(ui_->albums, SIGNAL(doubleClicked(QModelIndex)),
+          SLOT(AlbumDoubleClicked(QModelIndex)));
+  connect(ui_->action_add_to_playlist, SIGNAL(triggered()),
+          SLOT(AddSelectedToPlaylist()));
+  connect(ui_->action_load, SIGNAL(triggered()),
+          SLOT(LoadSelectedToPlaylist()));
 
   // Restore settings
   QSettings s;
@@ -196,18 +202,15 @@ void AlbumCoverManager::Init() {
     ui_->splitter->setSizes(QList<int>() << 200 << width() - 200);
   }
 
-  connect(app_->album_cover_loader(),
-          SIGNAL(ImageLoaded(quint64,QImage)),
-          SLOT(CoverImageLoaded(quint64,QImage)));
+  connect(app_->album_cover_loader(), SIGNAL(ImageLoaded(quint64, QImage)),
+          SLOT(CoverImageLoaded(quint64, QImage)));
 
   cover_searcher_->Init(cover_fetcher_);
 
   new ForceScrollPerPixel(ui_->albums, this);
 }
 
-void AlbumCoverManager::showEvent(QShowEvent *) {
-  Reset();
-}
+void AlbumCoverManager::showEvent(QShowEvent*) { Reset(); }
 
 void AlbumCoverManager::closeEvent(QCloseEvent* e) {
   if (!cover_fetching_tasks_.isEmpty()) {
@@ -236,7 +239,7 @@ void AlbumCoverManager::closeEvent(QCloseEvent* e) {
 
 void AlbumCoverManager::CancelRequests() {
   app_->album_cover_loader()->CancelTasks(
-        QSet<quint64>::fromList(cover_loading_tasks_.keys()));
+      QSet<quint64>::fromList(cover_loading_tasks_.keys()));
   cover_loading_tasks_.clear();
 
   cover_exporter_->Cancel();
@@ -262,15 +265,16 @@ void AlbumCoverManager::Reset() {
   EnableCoversButtons();
 
   ui_->artists->clear();
-  new QListWidgetItem(all_artists_icon_, tr("All artists"), ui_->artists, All_Artists);
-  new QListWidgetItem(artist_icon_, tr("Various artists"), ui_->artists, Various_Artists);
+  new QListWidgetItem(all_artists_icon_, tr("All artists"), ui_->artists,
+                      All_Artists);
+  new QListWidgetItem(artist_icon_, tr("Various artists"), ui_->artists,
+                      Various_Artists);
 
   QStringList artists(library_backend_->GetAllArtistsWithAlbums());
   qStableSort(artists.begin(), artists.end(), CompareNocase);
 
-  foreach (const QString& artist, artists) {
-    if (artist.isEmpty())
-      continue;
+  for (const QString& artist : artists) {
+    if (artist.isEmpty()) continue;
 
     new QListWidgetItem(artist_icon_, artist, ui_->artists, Specific_Artist);
   }
@@ -287,12 +291,10 @@ void AlbumCoverManager::DisableCoversButtons() {
 }
 
 void AlbumCoverManager::ArtistChanged(QListWidgetItem* current) {
-  if (!current)
-    return;
+  if (!current) return;
 
   QString artist;
-  if (current->type() == Specific_Artist)
-    artist = current->text();
+  if (current->type() == Specific_Artist) artist = current->text();
 
   ui_->albums->clear();
   context_menu_items_.clear();
@@ -302,33 +304,41 @@ void AlbumCoverManager::ArtistChanged(QListWidgetItem* current) {
   // selected in the artist list.
   LibraryBackend::AlbumList albums;
   switch (current->type()) {
-    case Various_Artists: albums = library_backend_->GetCompilationAlbums(); break;
-    case Specific_Artist: albums = library_backend_->GetAlbumsByArtist(current->text()); break;
+    case Various_Artists:
+      albums = library_backend_->GetCompilationAlbums();
+      break;
+    case Specific_Artist:
+      albums = library_backend_->GetAlbumsByArtist(current->text());
+      break;
     case All_Artists:
-    default:              albums = library_backend_->GetAllAlbums(); break;
+    default:
+      albums = library_backend_->GetAllAlbums();
+      break;
   }
 
   // Sort by album name.  The list is already sorted by sqlite but it was done
   // case sensitively.
   qStableSort(albums.begin(), albums.end(), CompareAlbumNameNocase);
 
-  foreach (const LibraryBackend::Album& info, albums) {
+  for (const LibraryBackend::Album& info : albums) {
     // Don't show songs without an album, obviously
-    if (info.album_name.isEmpty())
-      continue;
+    if (info.album_name.isEmpty()) continue;
 
-    QListWidgetItem* item = new QListWidgetItem(no_cover_icon_, info.album_name, ui_->albums);
+    QListWidgetItem* item =
+        new QListWidgetItem(no_cover_icon_, info.album_name, ui_->albums);
     item->setData(Role_ArtistName, info.artist);
     item->setData(Role_AlbumName, info.album_name);
     item->setData(Role_FirstUrl, info.first_url);
-    item->setData(Qt::TextAlignmentRole, QVariant(Qt::AlignTop | Qt::AlignHCenter));
-    item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled | Qt::ItemIsDragEnabled);
+    item->setData(Qt::TextAlignmentRole,
+                  QVariant(Qt::AlignTop | Qt::AlignHCenter));
+    item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled |
+                   Qt::ItemIsDragEnabled);
     item->setToolTip(info.artist + " - " + info.album_name);
 
     if (!info.art_automatic.isEmpty() || !info.art_manual.isEmpty()) {
       quint64 id = app_->album_cover_loader()->LoadImageAsync(
-          cover_loader_options_,
-          info.art_automatic, info.art_manual, info.first_url.toLocalFile());
+          cover_loader_options_, info.art_automatic, info.art_manual,
+          info.first_url.toLocalFile());
       item->setData(Role_PathAutomatic, info.art_automatic);
       item->setData(Role_PathManual, info.art_manual);
       cover_loading_tasks_[id] = item;
@@ -338,14 +348,12 @@ void AlbumCoverManager::ArtistChanged(QListWidgetItem* current) {
   UpdateFilter();
 }
 
-void AlbumCoverManager::CoverImageLoaded(quint64 id, const QImage &image) {
-  if (!cover_loading_tasks_.contains(id))
-    return;
+void AlbumCoverManager::CoverImageLoaded(quint64 id, const QImage& image) {
+  if (!cover_loading_tasks_.contains(id)) return;
 
   QListWidgetItem* item = cover_loading_tasks_.take(id);
 
-  if (image.isNull())
-    return;
+  if (image.isNull()) return;
 
   item->setIcon(QPixmap::fromImage(image));
   UpdateFilter();
@@ -383,8 +391,9 @@ void AlbumCoverManager::UpdateFilter() {
   ui_->without_cover->setText(QString::number(without_cover));
 }
 
-bool AlbumCoverManager::ShouldHide(
-    const QListWidgetItem& item, const QString& filter, HideCovers hide) const {
+bool AlbumCoverManager::ShouldHide(const QListWidgetItem& item,
+                                   const QString& filter,
+                                   HideCovers hide) const {
   bool has_cover = item.icon().cacheKey() != no_cover_icon_.cacheKey();
   if (hide == Hide_WithCovers && has_cover) {
     return true;
@@ -397,9 +406,10 @@ bool AlbumCoverManager::ShouldHide(
   }
 
   QStringList query = filter.split(' ');
-  foreach (const QString& s, query) {
-    if (!item.text().contains(s, Qt::CaseInsensitive)
-        && !item.data(Role_ArtistName).toString().contains(s, Qt::CaseInsensitive)) {
+  for (const QString& s : query) {
+    if (!item.text().contains(s, Qt::CaseInsensitive) &&
+        !item.data(Role_ArtistName).toString().contains(s,
+                                                        Qt::CaseInsensitive)) {
       return true;
     }
   }
@@ -408,21 +418,19 @@ bool AlbumCoverManager::ShouldHide(
 }
 
 void AlbumCoverManager::FetchAlbumCovers() {
-  for (int i=0 ; i<ui_->albums->count() ; ++i) {
+  for (int i = 0; i < ui_->albums->count(); ++i) {
     QListWidgetItem* item = ui_->albums->item(i);
-    if (item->isHidden())
-      continue;
-    if (item->icon().cacheKey() != no_cover_icon_.cacheKey())
-      continue;
+    if (item->isHidden()) continue;
+    if (item->icon().cacheKey() != no_cover_icon_.cacheKey()) continue;
 
-    quint64 id = cover_fetcher_->FetchAlbumCover(
-        item->data(Role_ArtistName).toString(), item->data(Role_AlbumName).toString());
+    quint64 id =
+        cover_fetcher_->FetchAlbumCover(item->data(Role_ArtistName).toString(),
+                                        item->data(Role_AlbumName).toString());
     cover_fetching_tasks_[id] = item;
-    jobs_ ++;
+    jobs_++;
   }
 
-  if (!cover_fetching_tasks_.isEmpty())
-    ui_->fetch->setEnabled(false);
+  if (!cover_fetching_tasks_.isEmpty()) ui_->fetch->setEnabled(false);
 
   progress_bar_->setMaximum(jobs_);
   progress_bar_->show();
@@ -431,10 +439,9 @@ void AlbumCoverManager::FetchAlbumCovers() {
   UpdateStatusText();
 }
 
-void AlbumCoverManager::AlbumCoverFetched(quint64 id, const QImage& image,
-                                          const CoverSearchStatistics& statistics) {
-  if (!cover_fetching_tasks_.contains(id))
-    return;
+void AlbumCoverManager::AlbumCoverFetched(
+    quint64 id, const QImage& image, const CoverSearchStatistics& statistics) {
+  if (!cover_fetching_tasks_.contains(id)) return;
 
   QListWidgetItem* item = cover_fetching_tasks_.take(id);
   if (!image.isNull()) {
@@ -451,13 +458,13 @@ void AlbumCoverManager::AlbumCoverFetched(quint64 id, const QImage& image,
 
 void AlbumCoverManager::UpdateStatusText() {
   QString message = tr("Got %1 covers out of %2 (%3 failed)")
-                    .arg(fetch_statistics_.chosen_images_)
-                    .arg(jobs_)
-                    .arg(fetch_statistics_.missing_images_);
+                        .arg(fetch_statistics_.chosen_images_)
+                        .arg(jobs_)
+                        .arg(fetch_statistics_.missing_images_);
 
   if (fetch_statistics_.bytes_transferred_) {
-    message += ", " + tr("%1 transferred")
-                      .arg(Utilities::PrettySize(fetch_statistics_.bytes_transferred_));
+    message += ", " + tr("%1 transferred").arg(Utilities::PrettySize(
+                          fetch_statistics_.bytes_transferred_));
   }
 
   statusBar()->showMessage(message);
@@ -477,24 +484,28 @@ void AlbumCoverManager::UpdateStatusText() {
   }
 }
 
-bool AlbumCoverManager::eventFilter(QObject *obj, QEvent *event) {
+bool AlbumCoverManager::eventFilter(QObject* obj, QEvent* event) {
   if (obj == ui_->albums && event->type() == QEvent::ContextMenu) {
     context_menu_items_ = ui_->albums->selectedItems();
-    if (context_menu_items_.isEmpty())
-      return false;
+    if (context_menu_items_.isEmpty()) return false;
 
     bool some_with_covers = false;
 
-    foreach (QListWidgetItem* item, context_menu_items_) {
+    for (QListWidgetItem* item : context_menu_items_) {
       if (item->icon().cacheKey() != no_cover_icon_.cacheKey())
         some_with_covers = true;
     }
 
-    album_cover_choice_controller_->cover_from_file_action()->setEnabled(context_menu_items_.size() == 1);
-    album_cover_choice_controller_->cover_from_url_action()->setEnabled(context_menu_items_.size() == 1);
-    album_cover_choice_controller_->show_cover_action()->setEnabled(some_with_covers && context_menu_items_.size() == 1);
-    album_cover_choice_controller_->unset_cover_action()->setEnabled(some_with_covers);
-    album_cover_choice_controller_->search_for_cover_action()->setEnabled(app_->cover_providers()->HasAnyProviders());
+    album_cover_choice_controller_->cover_from_file_action()->setEnabled(
+        context_menu_items_.size() == 1);
+    album_cover_choice_controller_->cover_from_url_action()->setEnabled(
+        context_menu_items_.size() == 1);
+    album_cover_choice_controller_->show_cover_action()->setEnabled(
+        some_with_covers && context_menu_items_.size() == 1);
+    album_cover_choice_controller_->unset_cover_action()->setEnabled(
+        some_with_covers);
+    album_cover_choice_controller_->search_for_cover_action()->setEnabled(
+        app_->cover_providers()->HasAnyProviders());
 
     QContextMenuEvent* e = static_cast<QContextMenuEvent*>(event);
     context_menu_->popup(e->globalPos());
@@ -504,15 +515,13 @@ bool AlbumCoverManager::eventFilter(QObject *obj, QEvent *event) {
 }
 
 Song AlbumCoverManager::GetSingleSelectionAsSong() {
-  return context_menu_items_.size() != 1
-             ? Song()
-             : ItemAsSong(context_menu_items_[0]);
+  return context_menu_items_.size() != 1 ? Song()
+                                         : ItemAsSong(context_menu_items_[0]);
 }
 
 Song AlbumCoverManager::GetFirstSelectedAsSong() {
-  return context_menu_items_.isEmpty()
-             ? Song()
-             : ItemAsSong(context_menu_items_[0]);
+  return context_menu_items_.isEmpty() ? Song()
+                                       : ItemAsSong(context_menu_items_[0]);
 }
 
 Song AlbumCoverManager::ItemAsSong(QListWidgetItem* item) {
@@ -541,18 +550,18 @@ Song AlbumCoverManager::ItemAsSong(QListWidgetItem* item) {
 
 void AlbumCoverManager::ShowCover() {
   Song song = GetSingleSelectionAsSong();
-  if(!song.is_valid())
-    return;
+  if (!song.is_valid()) return;
 
   album_cover_choice_controller_->ShowCover(song);
 }
 
 void AlbumCoverManager::FetchSingleCover() {
-  foreach (QListWidgetItem* item, context_menu_items_) {
-    quint64 id = cover_fetcher_->FetchAlbumCover(
-        item->data(Role_ArtistName).toString(), item->data(Role_AlbumName).toString());
+  for (QListWidgetItem* item : context_menu_items_) {
+    quint64 id =
+        cover_fetcher_->FetchAlbumCover(item->data(Role_ArtistName).toString(),
+                                        item->data(Role_AlbumName).toString());
     cover_fetching_tasks_[id] = item;
-    jobs_ ++;
+    jobs_++;
   }
 
   progress_bar_->setMaximum(jobs_);
@@ -561,18 +570,17 @@ void AlbumCoverManager::FetchSingleCover() {
   UpdateStatusText();
 }
 
-
-void AlbumCoverManager::UpdateCoverInList(QListWidgetItem* item, const QString& cover) {
-  quint64 id = app_->album_cover_loader()->LoadImageAsync(
-        cover_loader_options_, QString(), cover);
+void AlbumCoverManager::UpdateCoverInList(QListWidgetItem* item,
+                                          const QString& cover) {
+  quint64 id = app_->album_cover_loader()->LoadImageAsync(cover_loader_options_,
+                                                          QString(), cover);
   item->setData(Role_PathManual, cover);
   cover_loading_tasks_[id] = item;
 }
 
 void AlbumCoverManager::LoadCoverFromFile() {
   Song song = GetSingleSelectionAsSong();
-  if(!song.is_valid())
-    return;
+  if (!song.is_valid()) return;
 
   QListWidgetItem* item = context_menu_items_[0];
 
@@ -585,18 +593,18 @@ void AlbumCoverManager::LoadCoverFromFile() {
 
 void AlbumCoverManager::SaveCoverToFile() {
   Song song = GetSingleSelectionAsSong();
-  if(!song.is_valid())
-    return;
+  if (!song.is_valid()) return;
 
   QImage image;
 
   // load the image from disk
-  if(song.has_manually_unset_cover()) {
+  if (song.has_manually_unset_cover()) {
     image = QImage(":/nocover.png");
   } else {
-    if(!song.art_manual().isEmpty() && QFile::exists(song.art_manual())) {
+    if (!song.art_manual().isEmpty() && QFile::exists(song.art_manual())) {
       image = QImage(song.art_manual());
-    } else if(!song.art_automatic().isEmpty() && QFile::exists(song.art_automatic())) {
+    } else if (!song.art_automatic().isEmpty() &&
+               QFile::exists(song.art_automatic())) {
       image = QImage(song.art_automatic());
     } else {
       image = QImage(":/nocover.png");
@@ -608,8 +616,7 @@ void AlbumCoverManager::SaveCoverToFile() {
 
 void AlbumCoverManager::LoadCoverFromURL() {
   Song song = GetSingleSelectionAsSong();
-  if(!song.is_valid())
-    return;
+  if (!song.is_valid()) return;
 
   QListWidgetItem* item = context_menu_items_[0];
 
@@ -622,19 +629,17 @@ void AlbumCoverManager::LoadCoverFromURL() {
 
 void AlbumCoverManager::SearchForCover() {
   Song song = GetFirstSelectedAsSong();
-  if(!song.is_valid())
-    return;
+  if (!song.is_valid()) return;
 
   QListWidgetItem* item = context_menu_items_[0];
 
   QString cover = album_cover_choice_controller_->SearchForCover(&song);
-  if (cover.isEmpty())
-    return;
+  if (cover.isEmpty()) return;
 
   // force the found cover on all of the selected items
-  foreach (QListWidgetItem* current, context_menu_items_) {
+  for (QListWidgetItem* current : context_menu_items_) {
     // don't save the first one twice
-    if(current != item) {
+    if (current != item) {
       Song current_song = ItemAsSong(current);
       album_cover_choice_controller_->SaveCover(&current_song, cover);
     }
@@ -645,20 +650,19 @@ void AlbumCoverManager::SearchForCover() {
 
 void AlbumCoverManager::UnsetCover() {
   Song song = GetFirstSelectedAsSong();
-  if(!song.is_valid())
-    return;
+  if (!song.is_valid()) return;
 
   QListWidgetItem* item = context_menu_items_[0];
 
   QString cover = album_cover_choice_controller_->UnsetCover(&song);
 
   // force the 'none' cover on all of the selected items
-  foreach (QListWidgetItem* current, context_menu_items_) {
+  for (QListWidgetItem* current : context_menu_items_) {
     current->setIcon(no_cover_icon_);
     current->setData(Role_PathManual, cover);
 
     // don't save the first one twice
-    if(current != item) {
+    if (current != item) {
       Song current_song = ItemAsSong(current);
       album_cover_choice_controller_->SaveCover(&current_song, cover);
     }
@@ -675,11 +679,9 @@ SongList AlbumCoverManager::GetSongsInAlbum(const QModelIndex& index) const {
 
   QString artist = index.data(Role_ArtistName).toString();
   q.AddCompilationRequirement(artist.isEmpty());
-  if (!artist.isEmpty())
-    q.AddWhere("artist", artist);
+  if (!artist.isEmpty()) q.AddWhere("artist", artist);
 
-  if (!library_backend_->ExecQuery(&q))
-    return ret;
+  if (!library_backend_->ExecQuery(&q)) return ret;
 
   while (q.Next()) {
     Song song;
@@ -689,18 +691,19 @@ SongList AlbumCoverManager::GetSongsInAlbum(const QModelIndex& index) const {
   return ret;
 }
 
-SongList AlbumCoverManager::GetSongsInAlbums(const QModelIndexList& indexes) const {
+SongList AlbumCoverManager::GetSongsInAlbums(const QModelIndexList& indexes)
+    const {
   SongList ret;
-  foreach (const QModelIndex& index, indexes) {
+  for (const QModelIndex& index : indexes) {
     ret << GetSongsInAlbum(index);
   }
   return ret;
 }
 
-SongMimeData* AlbumCoverManager::GetMimeDataForAlbums(const QModelIndexList& indexes) const {
+SongMimeData* AlbumCoverManager::GetMimeDataForAlbums(
+    const QModelIndexList& indexes) const {
   SongList songs = GetSongsInAlbums(indexes);
-  if (songs.isEmpty())
-    return NULL;
+  if (songs.isEmpty()) return nullptr;
 
   SongMimeData* data = new SongMimeData;
   data->backend = library_backend_;
@@ -708,7 +711,7 @@ SongMimeData* AlbumCoverManager::GetMimeDataForAlbums(const QModelIndexList& ind
   return data;
 }
 
-void AlbumCoverManager::AlbumDoubleClicked(const QModelIndex &index) {
+void AlbumCoverManager::AlbumDoubleClicked(const QModelIndex& index) {
   SongMimeData* data = GetMimeDataForAlbums(QModelIndexList() << index);
   if (data) {
     data->from_doubleclick_ = true;
@@ -717,29 +720,33 @@ void AlbumCoverManager::AlbumDoubleClicked(const QModelIndex &index) {
 }
 
 void AlbumCoverManager::AddSelectedToPlaylist() {
-  emit AddToPlaylist(GetMimeDataForAlbums(ui_->albums->selectionModel()->selectedIndexes()));
+  emit AddToPlaylist(
+      GetMimeDataForAlbums(ui_->albums->selectionModel()->selectedIndexes()));
 }
 
 void AlbumCoverManager::LoadSelectedToPlaylist() {
-  SongMimeData* data = GetMimeDataForAlbums(ui_->albums->selectionModel()->selectedIndexes());
+  SongMimeData* data =
+      GetMimeDataForAlbums(ui_->albums->selectionModel()->selectedIndexes());
   if (data) {
     data->clear_first_ = true;
     emit AddToPlaylist(data);
   }
 }
 
-void AlbumCoverManager::SaveAndSetCover(QListWidgetItem *item, const QImage &image) {
+void AlbumCoverManager::SaveAndSetCover(QListWidgetItem* item,
+                                        const QImage& image) {
   const QString artist = item->data(Role_ArtistName).toString();
   const QString album = item->data(Role_AlbumName).toString();
 
-  QString path = album_cover_choice_controller_->SaveCoverInCache(artist, album, image);
+  QString path =
+      album_cover_choice_controller_->SaveCoverInCache(artist, album, image);
 
   // Save the image in the database
   library_backend_->UpdateManualAlbumArtAsync(artist, album, path);
 
   // Update the icon in our list
-  quint64 id = app_->album_cover_loader()->LoadImageAsync(
-        cover_loader_options_, QString(), path);
+  quint64 id = app_->album_cover_loader()->LoadImageAsync(cover_loader_options_,
+                                                          QString(), path);
   item->setData(Role_PathManual, path);
   cover_loading_tasks_[id] = item;
 }
@@ -747,7 +754,7 @@ void AlbumCoverManager::SaveAndSetCover(QListWidgetItem *item, const QImage &ima
 void AlbumCoverManager::ExportCovers() {
   AlbumCoverExport::DialogResult result = cover_export_->Exec();
 
-  if(result.cancelled_) {
+  if (result.cancelled_) {
     return;
   }
 
@@ -755,11 +762,12 @@ void AlbumCoverManager::ExportCovers() {
 
   cover_exporter_->SetDialogResult(result);
 
-  for (int i=0 ; i<ui_->albums->count() ; ++i) {
+  for (int i = 0; i < ui_->albums->count(); ++i) {
     QListWidgetItem* item = ui_->albums->item(i);
 
     // skip hidden and coverless albums
-    if (item->isHidden() || item->icon().cacheKey() == no_cover_icon_.cacheKey()) {
+    if (item->isHidden() ||
+        item->icon().cacheKey() == no_cover_icon_.cacheKey()) {
       continue;
     }
 
@@ -784,13 +792,13 @@ void AlbumCoverManager::UpdateExportStatus(int exported, int skipped, int max) {
   progress_bar_->setValue(exported);
 
   QString message = tr("Exported %1 covers out of %2 (%3 skipped)")
-                      .arg(exported)
-                      .arg(max)
-                      .arg(skipped);
+                        .arg(exported)
+                        .arg(max)
+                        .arg(skipped);
   statusBar()->showMessage(message);
 
   // end of the current process
-  if(exported + skipped >= max) {
+  if (exported + skipped >= max) {
     QTimer::singleShot(2000, statusBar(), SLOT(clearMessage()));
 
     progress_bar_->hide();
