@@ -15,26 +15,14 @@
    along with Clementine.  If not, see <http://www.gnu.org/licenses/>.
 */
 
-#include "albumcovermanager.h"
-#include "edittagdialog.h"
-#include "trackselectiondialog.h"
+#include "ui/edittagdialog.h"
 #include "ui_edittagdialog.h"
-#include "core/application.h"
-#include "core/logging.h"
-#include "core/tagreaderclient.h"
-#include "core/utilities.h"
-#include "covers/albumcoverloader.h"
-#include "covers/coverproviders.h"
-#include "library/library.h"
-#include "library/librarybackend.h"
-#include "playlist/playlistdelegates.h"
-#include "ui/albumcoverchoicecontroller.h"
-#include "ui/coverfromurldialog.h"
+
+#include <limits>
 
 #include <QDateTime>
 #include <QDir>
 #include <QFuture>
-#include <QFutureWatcher>
 #include <QLabel>
 #include <QMenu>
 #include <QMessageBox>
@@ -43,34 +31,48 @@
 #include <QtConcurrentRun>
 #include <QtDebug>
 
-#include <limits>
+#include "core/application.h"
+#include "core/logging.h"
+#include "core/tagreaderclient.h"
+#include "core/utilities.h"
+#include "covers/albumcoverloader.h"
+#include "covers/coverproviders.h"
+#include "library/librarybackend.h"
+#include "library/library.h"
+#include "playlist/playlistdelegates.h"
+#include "ui/albumcoverchoicecontroller.h"
+#include "ui/albumcovermanager.h"
+#include "ui/coverfromurldialog.h"
+#include "ui/iconloader.h"
+#include "ui/trackselectiondialog.h"
 
-const char* EditTagDialog::kHintText = QT_TR_NOOP("(different across multiple songs)");
+const char* EditTagDialog::kHintText =
+    QT_TR_NOOP("(different across multiple songs)");
 const char* EditTagDialog::kSettingsGroup = "EditTagDialog";
 
 EditTagDialog::EditTagDialog(Application* app, QWidget* parent)
-  : QDialog(parent),
-    ui_(new Ui_EditTagDialog),
-    app_(app),
-    album_cover_choice_controller_(new AlbumCoverChoiceController(this)),
-    loading_(false),
-    ignore_edits_(false),
-    tag_fetcher_(new TagFetcher(this)),
-    cover_art_id_(0),
-    cover_art_is_set_(false),
-    results_dialog_(new TrackSelectionDialog(this))
-{
+    : QDialog(parent),
+      ui_(new Ui_EditTagDialog),
+      app_(app),
+      album_cover_choice_controller_(new AlbumCoverChoiceController(this)),
+      loading_(false),
+      ignore_edits_(false),
+      tag_fetcher_(new TagFetcher(this)),
+      cover_art_id_(0),
+      cover_art_is_set_(false),
+      results_dialog_(new TrackSelectionDialog(this)) {
   cover_options_.default_output_image_ =
       AlbumCoverLoader::ScaleAndPad(cover_options_, QImage(":nocover.png"));
 
-  connect(app_->album_cover_loader(), SIGNAL(ImageLoaded(quint64,QImage,QImage)),
-          SLOT(ArtLoaded(quint64,QImage,QImage)));
+  connect(app_->album_cover_loader(),
+          SIGNAL(ImageLoaded(quint64, QImage, QImage)),
+          SLOT(ArtLoaded(quint64, QImage, QImage)));
 
   connect(tag_fetcher_, SIGNAL(ResultAvailable(Song, SongList)),
           results_dialog_, SLOT(FetchTagFinished(Song, SongList)),
           Qt::QueuedConnection);
-  connect(tag_fetcher_, SIGNAL(Progress(Song,QString)),
-          results_dialog_, SLOT(FetchTagProgress(Song,QString)));
+  connect(tag_fetcher_, SIGNAL(Progress(Song, QString)), results_dialog_,
+          SLOT(FetchTagProgress(Song, QString)));
   connect(results_dialog_, SIGNAL(SongChosen(Song, Song)),
           SLOT(FetchTagSongChosen(Song, Song)));
   connect(results_dialog_, SIGNAL(finished(int)), tag_fetcher_, SLOT(Cancel()));
@@ -81,9 +83,12 @@ EditTagDialog::EditTagDialog(Application* app, QWidget* parent)
   ui_->splitter->setSizes(QList<int>() << 200 << width() - 200);
   ui_->loading_label->hide();
 
+  ui_->fetch_tag->setIcon(IconLoader::Load("musicbrainz", 
+                          IconLoader::Provider));
+
   // An editable field is one that has a label as a buddy.  The label is
   // important because it gets turned bold when the field is changed.
-  foreach (QLabel* label, findChildren<QLabel*>()) {
+  for (QLabel* label : findChildren<QLabel*>()) {
     QWidget* widget = label->buddy();
     if (widget) {
       // Store information about the field
@@ -107,27 +112,27 @@ EditTagDialog::EditTagDialog(Application* app, QWidget* parent)
 
   // Set the colour of all the labels on the summary page
   const bool light = palette().color(QPalette::Base).value() > 128;
-  const QColor color = palette().color(QPalette::Dark);
+  const QColor color = palette().color(QPalette::WindowText);
   QPalette summary_label_palette(palette());
-  summary_label_palette.setColor(QPalette::WindowText,
-      light ? color.darker(150) : color.lighter(125));
+  summary_label_palette.setColor(
+      QPalette::WindowText, light ? color.lighter(150) : color.darker(150));
 
-  foreach (QLabel* label, ui_->summary_tab->findChildren<QLabel*>()) {
+  for (QLabel* label : ui_->summary_tab->findChildren<QLabel*>()) {
     if (label->property("field_label").toBool()) {
       label->setPalette(summary_label_palette);
     }
   }
 
   // Pretend the summary text is just a label
-  ui_->summary->setMaximumHeight(ui_->art->height() - ui_->summary_art_button->height() - 4);
+  ui_->summary->setMaximumHeight(ui_->art->height() -
+                                 ui_->summary_art_button->height() - 4);
 
   connect(ui_->song_list->selectionModel(),
-          SIGNAL(selectionChanged(QItemSelection,QItemSelection)),
+          SIGNAL(selectionChanged(QItemSelection, QItemSelection)),
           SLOT(SelectionChanged()));
   connect(ui_->button_box, SIGNAL(clicked(QAbstractButton*)),
-                           SLOT(ButtonClicked(QAbstractButton*)));
-  connect(ui_->rating, SIGNAL(RatingChanged(float)),
-                       SLOT(SongRated(float)));
+          SLOT(ButtonClicked(QAbstractButton*)));
+  connect(ui_->rating, SIGNAL(RatingChanged(float)), SLOT(SongRated(float)));
   connect(ui_->playcount_reset, SIGNAL(clicked()), SLOT(ResetPlayCounts()));
   connect(ui_->fetch_tag, SIGNAL(clicked()), SLOT(FetchTag()));
 
@@ -157,8 +162,10 @@ EditTagDialog::EditTagDialog(Application* app, QWidget* parent)
   ui_->art->setAcceptDrops(true);
 
   // Add the next/previous buttons
-  previous_button_ = new QPushButton(IconLoader::Load("go-previous"), tr("Previous"), this);
-  next_button_ = new QPushButton(IconLoader::Load("go-next"), tr("Next"), this);
+  previous_button_ = new QPushButton(
+      IconLoader::Load("go-previous", IconLoader::Base), tr("Previous"), this);
+  next_button_ = new QPushButton(IconLoader::Load("go-next", IconLoader::Base),
+                                 tr("Next"), this);
   ui_->button_box->addButton(previous_button_, QDialogButtonBox::ResetRole);
   ui_->button_box->addButton(next_button_, QDialogButtonBox::ResetRole);
 
@@ -168,36 +175,41 @@ EditTagDialog::EditTagDialog(Application* app, QWidget* parent)
   // Set some shortcuts for the buttons
   new QShortcut(QKeySequence::Back, previous_button_, SLOT(click()));
   new QShortcut(QKeySequence::Forward, next_button_, SLOT(click()));
-  new QShortcut(QKeySequence::MoveToPreviousPage, previous_button_, SLOT(click()));
+  new QShortcut(QKeySequence::MoveToPreviousPage, previous_button_,
+                SLOT(click()));
   new QShortcut(QKeySequence::MoveToNextPage, next_button_, SLOT(click()));
 
   // Show the shortcuts as tooltips
   previous_button_->setToolTip(QString("%1 (%2 / %3)").arg(
       previous_button_->text(),
       QKeySequence(QKeySequence::Back).toString(QKeySequence::NativeText),
-      QKeySequence(QKeySequence::MoveToPreviousPage).toString(QKeySequence::NativeText)));
+      QKeySequence(QKeySequence::MoveToPreviousPage)
+          .toString(QKeySequence::NativeText)));
   next_button_->setToolTip(QString("%1 (%2 / %3)").arg(
       next_button_->text(),
       QKeySequence(QKeySequence::Forward).toString(QKeySequence::NativeText),
-      QKeySequence(QKeySequence::MoveToNextPage).toString(QKeySequence::NativeText)));
+      QKeySequence(QKeySequence::MoveToNextPage)
+          .toString(QKeySequence::NativeText)));
 
-  new TagCompleter(app_->library_backend(), Playlist::Column_Artist, ui_->artist);
+  new TagCompleter(app_->library_backend(), Playlist::Column_Artist,
+                   ui_->artist);
   new TagCompleter(app_->library_backend(), Playlist::Column_Album, ui_->album);
-  new TagCompleter(app_->library_backend(), Playlist::Column_AlbumArtist, ui_->albumartist);
+  new TagCompleter(app_->library_backend(), Playlist::Column_AlbumArtist,
+                   ui_->albumartist);
   new TagCompleter(app_->library_backend(), Playlist::Column_Genre, ui_->genre);
-  new TagCompleter(app_->library_backend(), Playlist::Column_Composer, ui_->composer);
-  new TagCompleter(app_->library_backend(), Playlist::Column_Performer, ui_->performer);
-  new TagCompleter(app_->library_backend(), Playlist::Column_Grouping, ui_->grouping);
+  new TagCompleter(app_->library_backend(), Playlist::Column_Composer,
+                   ui_->composer);
+  new TagCompleter(app_->library_backend(), Playlist::Column_Performer,
+                   ui_->performer);
+  new TagCompleter(app_->library_backend(), Playlist::Column_Grouping,
+                   ui_->grouping);
 }
 
-EditTagDialog::~EditTagDialog() {
-  delete ui_;
-}
+EditTagDialog::~EditTagDialog() { delete ui_; }
 
 bool EditTagDialog::SetLoading(const QString& message) {
   const bool loading = !message.isEmpty();
-  if (loading == loading_)
-    return false;
+  if (loading == loading_) return false;
   loading_ = loading;
 
   ui_->button_box->setEnabled(!loading);
@@ -209,14 +221,16 @@ bool EditTagDialog::SetLoading(const QString& message) {
   return true;
 }
 
-QList<EditTagDialog::Data> EditTagDialog::LoadData(const SongList& songs) const {
+QList<EditTagDialog::Data> EditTagDialog::LoadData(
+    const SongList& songs) const {
   QList<Data> ret;
 
-  foreach (const Song& song, songs) {
+  for (const Song& song : songs) {
     if (song.IsEditable()) {
       // Try reloading the tags from file
       Song copy(song);
-      TagReaderClient::Instance()->ReadFileBlocking(copy.url().toLocalFile(), &copy);
+      TagReaderClient::Instance()->ReadFileBlocking(copy.url().toLocalFile(),
+                                                    &copy);
 
       if (copy.is_valid()) {
         copy.MergeUserSetData(song);
@@ -230,30 +244,24 @@ QList<EditTagDialog::Data> EditTagDialog::LoadData(const SongList& songs) const
 
 void EditTagDialog::SetSongs(const SongList& s, const PlaylistItemList& items) {
   // Show the loading indicator
-  if (!SetLoading(tr("Loading tracks") + "..."))
-    return;
+  if (!SetLoading(tr("Loading tracks") + "...")) return;
 
   data_.clear();
   playlist_items_ = items;
   ui_->song_list->clear();
 
   // Reload tags in the background
-  QFuture<QList<Data> > future = QtConcurrent::run(this, &EditTagDialog::LoadData, s);
-  QFutureWatcher<QList<Data> >* watcher = new QFutureWatcher<QList<Data> >(this);
-  watcher->setFuture(future);
-  connect(watcher, SIGNAL(finished()), SLOT(SetSongsFinished()));
+  QFuture<QList<Data>> future =
+      QtConcurrent::run(this, &EditTagDialog::LoadData, s);
+  NewClosure(future, this,
+             SLOT(SetSongsFinished(QFuture<QList<EditTagDialog::Data>>)),
+             future);
 }
 
-void EditTagDialog::SetSongsFinished() {
-  QFutureWatcher<QList<Data> >* watcher = dynamic_cast<QFutureWatcher<QList<Data> >*>(sender());
-  if (!watcher)
-    return;
-  watcher->deleteLater();
+void EditTagDialog::SetSongsFinished(QFuture<QList<Data>> future) {
+  if (!SetLoading(QString())) return;
 
-  if (!SetLoading(QString()))
-    return;
-
-  data_ = watcher->result();
+  data_ = future.result();
   if (data_.count() == 0) {
     // If there were no valid songs, disable everything
     ui_->song_list->setEnabled(false);
@@ -268,7 +276,7 @@ void EditTagDialog::SetSongsFinished() {
   }
 
   // Add the filenames to the list
-  foreach (const Data& data, data_) {
+  for (const Data& data : data_) {
     ui_->song_list->addItem(data.current_.basefilename());
   }
 
@@ -287,55 +295,74 @@ void EditTagDialog::SetSongListVisibility(bool visible) {
 }
 
 QVariant EditTagDialog::Data::value(const Song& song, const QString& id) {
-  if (id == "title")       return song.title();
-  if (id == "artist")      return song.artist();
-  if (id == "album")       return song.album();
+  if (id == "title") return song.title();
+  if (id == "artist") return song.artist();
+  if (id == "album") return song.album();
   if (id == "albumartist") return song.albumartist();
-  if (id == "composer")    return song.composer();
-  if (id == "performer")   return song.performer();
-  if (id == "grouping")    return song.grouping();
-  if (id == "genre")       return song.genre();
-  if (id == "comment")     return song.comment();
-  if (id == "track")       return song.track();
-  if (id == "disc")        return song.disc();
-  if (id == "year")        return song.year();
+  if (id == "composer") return song.composer();
+  if (id == "performer") return song.performer();
+  if (id == "grouping") return song.grouping();
+  if (id == "genre") return song.genre();
+  if (id == "comment") return song.comment();
+  if (id == "lyrics") return song.lyrics();
+  if (id == "track") return song.track();
+  if (id == "disc") return song.disc();
+  if (id == "year") return song.year();
   qLog(Warning) << "Unknown ID" << id;
   return QVariant();
 }
 
 void EditTagDialog::Data::set_value(const QString& id, const QVariant& value) {
-  if (id == "title")       current_.set_title(value.toString());
-  if (id == "artist")      current_.set_artist(value.toString());
-  if (id == "album")       current_.set_album(value.toString());
-  if (id == "albumartist") current_.set_albumartist(value.toString());
-  if (id == "composer")    current_.set_composer(value.toString());
-  if (id == "performer")   current_.set_performer(value.toString());
-  if (id == "grouping")    current_.set_grouping(value.toString());
-  if (id == "genre")       current_.set_genre(value.toString());
-  if (id == "comment")     current_.set_comment(value.toString());
-  if (id == "track")       current_.set_track(value.toInt());
-  if (id == "disc")        current_.set_disc(value.toInt());
-  if (id == "year")        current_.set_year(value.toInt());
+  if (id == "title")
+    current_.set_title(value.toString());
+  else if (id == "artist")
+    current_.set_artist(value.toString());
+  else if (id == "album")
+    current_.set_album(value.toString());
+  else if (id == "albumartist")
+    current_.set_albumartist(value.toString());
+  else if (id == "composer")
+    current_.set_composer(value.toString());
+  else if (id == "performer")
+    current_.set_performer(value.toString());
+  else if (id == "grouping")
+    current_.set_grouping(value.toString());
+  else if (id == "genre")
+    current_.set_genre(value.toString());
+  else if (id == "comment")
+    current_.set_comment(value.toString());
+  else if (id == "lyrics")
+    current_.set_lyrics(value.toString());
+  else if (id == "track")
+    current_.set_track(value.toInt());
+  else if (id == "disc")
+    current_.set_disc(value.toInt());
+  else if (id == "year")
+    current_.set_year(value.toInt());
+  else
+    qLog(Warning) << "Unknown ID" << id;
 }
 
-bool EditTagDialog::DoesValueVary(const QModelIndexList& sel, const QString& id) const {
+bool EditTagDialog::DoesValueVary(const QModelIndexList& sel,
+                                  const QString& id) const {
   QVariant value = data_[sel.first().row()].current_value(id);
-  for (int i=1 ; i<sel.count() ; ++i) {
-    if (value != data_[sel[i].row()].current_value(id))
-      return true;
+  for (int i = 1; i < sel.count(); ++i) {
+    if (value != data_[sel[i].row()].current_value(id)) return true;
   }
   return false;
 }
 
-bool EditTagDialog::IsValueModified(const QModelIndexList& sel, const QString& id) const {
-  foreach (const QModelIndex& i, sel) {
+bool EditTagDialog::IsValueModified(const QModelIndexList& sel,
+                                    const QString& id) const {
+  for (const QModelIndex& i : sel) {
     if (data_[i.row()].original_value(id) != data_[i.row()].current_value(id))
       return true;
   }
   return false;
 }
 
-void EditTagDialog::InitFieldValue(const FieldData& field, const QModelIndexList& sel) {
+void EditTagDialog::InitFieldValue(const FieldData& field,
+                                   const QModelIndexList& sel) {
   const bool varies = DoesValueVary(sel, field.id_);
   const bool modified = IsValueModified(sel, field.id_);
 
@@ -343,7 +370,7 @@ void EditTagDialog::InitFieldValue(const FieldData& field, const QModelIndexList
     editor->clear();
     editor->clear_hint();
     if (varies) {
-      editor->set_hint(EditTagDialog::kHintText);
+      editor->set_hint(tr(EditTagDialog::kHintText));
     } else {
       editor->set_text(data_[sel[0].row()].current_value(field.id_).toString());
     }
@@ -355,7 +382,8 @@ void EditTagDialog::InitFieldValue(const FieldData& field, const QModelIndexList
   field.editor_->setFont(new_font);
 }
 
-void EditTagDialog::UpdateFieldValue(const FieldData& field, const QModelIndexList& sel) {
+void EditTagDialog::UpdateFieldValue(const FieldData& field,
+                                     const QModelIndexList& sel) {
   // Get the value from the field
   QVariant value;
   if (ExtendedEditor* editor = dynamic_cast<ExtendedEditor*>(field.editor_)) {
@@ -368,7 +396,7 @@ void EditTagDialog::UpdateFieldValue(const FieldData& field, const QModelIndexLi
   }
 
   // Set it in each selected song
-  foreach (const QModelIndex& i, sel) {
+  for (const QModelIndex& i : sel) {
     data_[i.row()].set_value(field.id_, value);
   }
 
@@ -381,9 +409,10 @@ void EditTagDialog::UpdateFieldValue(const FieldData& field, const QModelIndexLi
   field.editor_->setFont(new_font);
 }
 
-void EditTagDialog::ResetFieldValue(const FieldData& field, const QModelIndexList& sel) {
+void EditTagDialog::ResetFieldValue(const FieldData& field,
+                                    const QModelIndexList& sel) {
   // Reset each selected song
-  foreach (const QModelIndex& i, sel) {
+  for (const QModelIndex& i : sel) {
     Data& data = data_[i.row()];
     data.set_value(field.id_, data.original_value(field.id_));
   }
@@ -393,20 +422,21 @@ void EditTagDialog::ResetFieldValue(const FieldData& field, const QModelIndexLis
 }
 
 void EditTagDialog::SelectionChanged() {
-  const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
-  if (sel.isEmpty())
-    return;
+  const QModelIndexList sel =
+      ui_->song_list->selectionModel()->selectedIndexes();
+  if (sel.isEmpty()) return;
 
   // Set the editable fields
   ignore_edits_ = true;
-  foreach (const FieldData& field, fields_) {
+  for (const FieldData& field : fields_) {
     InitFieldValue(field, sel);
   }
   ignore_edits_ = false;
 
   // If we're editing multiple songs then we have to disable certain tabs
   const bool multiple = sel.count() > 1;
-  ui_->tab_widget->setTabEnabled(ui_->tab_widget->indexOf(ui_->summary_tab), !multiple);
+  ui_->tab_widget->setTabEnabled(ui_->tab_widget->indexOf(ui_->summary_tab),
+                                 !multiple);
 
   if (!multiple) {
     const Song& song = data_[sel.first().row()].original_;
@@ -415,12 +445,13 @@ void EditTagDialog::SelectionChanged() {
   }
 }
 
-static void SetText(QLabel* label, int value, const QString& suffix, const QString& def = QString()) {
+static void SetText(QLabel* label, int value, const QString& suffix,
+                    const QString& def = QString()) {
   label->setText(value <= 0 ? def : (QString::number(value) + " " + suffix));
 }
 
 static void SetDate(QLabel* label, uint time) {
-  if (time == std::numeric_limits<uint>::max()) { // -1
+  if (time == std::numeric_limits<uint>::max()) {  // -1
     label->setText(QObject::tr("Unknown"));
   } else {
     label->setText(QDateTime::fromTime_t(time).toString(
@@ -429,9 +460,11 @@ static void SetDate(QLabel* label, uint time) {
 }
 
 void EditTagDialog::UpdateSummaryTab(const Song& song) {
-  cover_art_id_ = app_->album_cover_loader()->LoadImageAsync(cover_options_, song);
+  cover_art_id_ =
+      app_->album_cover_loader()->LoadImageAsync(cover_options_, song);
 
-  QString summary = "<b>" + Qt::escape(song.PrettyTitleWithArtist()) + "</b><br/>";
+  QString summary =
+      "<b>" + Qt::escape(song.PrettyTitleWithArtist()) + "</b><br/>";
 
   bool art_is_set = true;
   if (song.has_manually_unset_cover()) {
@@ -442,7 +475,8 @@ void EditTagDialog::UpdateSummaryTab(const Song& song) {
   } else if (song.has_embedded_cover()) {
     summary += Qt::escape(tr("Cover art from embedded image"));
   } else if (!song.art_automatic().isEmpty()) {
-    summary += Qt::escape(tr("Cover art loaded automatically from %1").arg(song.art_automatic()));
+    summary += Qt::escape(
+        tr("Cover art loaded automatically from %1").arg(song.art_automatic()));
   } else {
     summary += Qt::escape(tr("Cover art not set"));
     art_is_set = false;
@@ -475,7 +509,7 @@ void EditTagDialog::UpdateSummaryTab(const Song& song) {
     ui_->filename->setText(song.url().toString());
 
   album_cover_choice_controller_->search_for_cover_action()->setEnabled(
-        app_->cover_providers()->HasAnyProviders());
+      app_->cover_providers()->HasAnyProviders());
 }
 
 void EditTagDialog::UpdateStatisticsTab(const Song& song) {
@@ -484,12 +518,15 @@ void EditTagDialog::UpdateStatisticsTab(const Song& song) {
   ui_->score->setText(QString::number(qMax(0, song.score())));
   ui_->rating->set_rating(song.rating());
 
-  ui_->lastplayed->setText(song.lastplayed() <= 0 ? tr("Never") :
-      QDateTime::fromTime_t(song.lastplayed()).toString(
-          QLocale::system().dateTimeFormat(QLocale::LongFormat)));
+  ui_->lastplayed->setText(
+      song.lastplayed() <= 0
+          ? tr("Never")
+          : QDateTime::fromTime_t(song.lastplayed()).toString(
+                QLocale::system().dateTimeFormat(QLocale::LongFormat)));
 }
 
-void EditTagDialog::ArtLoaded(quint64 id, const QImage& scaled, const QImage& original) {
+void EditTagDialog::ArtLoaded(quint64 id, const QImage& scaled,
+                              const QImage& original) {
   if (id == cover_art_id_) {
     ui_->art->setPixmap(QPixmap::fromImage(scaled));
     original_ = original;
@@ -497,17 +534,16 @@ void EditTagDialog::ArtLoaded(quint64 id, const QImage& scaled, const QImage& or
 }
 
 void EditTagDialog::FieldValueEdited() {
-  if (ignore_edits_)
-    return;
+  if (ignore_edits_) return;
 
-  const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
-  if (sel.isEmpty())
-    return;
+  const QModelIndexList sel =
+      ui_->song_list->selectionModel()->selectedIndexes();
+  if (sel.isEmpty()) return;
 
   QWidget* w = qobject_cast<QWidget*>(sender());
 
   // Find the field
-  foreach (const FieldData& field, fields_) {
+  for (const FieldData& field : fields_) {
     if (field.editor_ == w) {
       UpdateFieldValue(field, sel);
       return;
@@ -516,14 +552,14 @@ void EditTagDialog::FieldValueEdited() {
 }
 
 void EditTagDialog::ResetField() {
-  const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
-  if (sel.isEmpty())
-    return;
+  const QModelIndexList sel =
+      ui_->song_list->selectionModel()->selectedIndexes();
+  if (sel.isEmpty()) return;
 
   QWidget* w = qobject_cast<QWidget*>(sender());
 
   // Find the field
-  foreach (const FieldData& field, fields_) {
+  for (const FieldData& field : fields_) {
     if (field.editor_ == w) {
       ignore_edits_ = true;
       ResetFieldValue(field, sel);
@@ -534,65 +570,61 @@ void EditTagDialog::ResetField() {
 }
 
 Song* EditTagDialog::GetFirstSelected() {
-  const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
-  if (sel.isEmpty())
-    return NULL;
+  const QModelIndexList sel =
+      ui_->song_list->selectionModel()->selectedIndexes();
+  if (sel.isEmpty()) return nullptr;
   return &data_[sel.first().row()].original_;
 }
 
 void EditTagDialog::LoadCoverFromFile() {
   Song* song = GetFirstSelected();
-  if(!song)
-    return;
+  if (!song) return;
 
-  const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
+  const QModelIndexList sel =
+      ui_->song_list->selectionModel()->selectedIndexes();
 
   QString cover = album_cover_choice_controller_->LoadCoverFromFile(song);
 
-  if(!cover.isEmpty())
-    UpdateCoverOf(*song, sel, cover);
+  if (!cover.isEmpty()) UpdateCoverOf(*song, sel, cover);
 }
 
 void EditTagDialog::SaveCoverToFile() {
   Song* song = GetFirstSelected();
-  if(!song)
-    return;
+  if (!song) return;
 
   album_cover_choice_controller_->SaveCoverToFile(*song, original_);
 }
 
 void EditTagDialog::LoadCoverFromURL() {
   Song* song = GetFirstSelected();
-  if(!song)
-    return;
+  if (!song) return;
 
-  const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
+  const QModelIndexList sel =
+      ui_->song_list->selectionModel()->selectedIndexes();
 
   QString cover = album_cover_choice_controller_->LoadCoverFromURL(song);
 
-  if(!cover.isEmpty())
-    UpdateCoverOf(*song, sel, cover);
+  if (!cover.isEmpty()) UpdateCoverOf(*song, sel, cover);
 }
 
 void EditTagDialog::SearchForCover() {
   Song* song = GetFirstSelected();
-  if(!song)
-    return;
+  if (!song) return;
 
-  const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
+  const QModelIndexList sel =
+      ui_->song_list->selectionModel()->selectedIndexes();
 
   QString cover = album_cover_choice_controller_->SearchForCover(song);
 
-  if(!cover.isEmpty())
-    UpdateCoverOf(*song, sel, cover);
+  if (!cover.isEmpty()) UpdateCoverOf(*song, sel, cover);
 }
 
 void EditTagDialog::UnsetCover() {
   Song* song = GetFirstSelected();
-  if(!song)
-    return;
+  if (!song) return;
 
-  const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
+  const QModelIndexList sel =
+      ui_->song_list->selectionModel()->selectedIndexes();
 
   QString cover = album_cover_choice_controller_->UnsetCover(song);
   UpdateCoverOf(*song, sel, cover);
@@ -600,29 +632,29 @@ void EditTagDialog::UnsetCover() {
 
 void EditTagDialog::ShowCover() {
   Song* song = GetFirstSelected();
-  if(!song) {
+  if (!song) {
     return;
   }
 
   album_cover_choice_controller_->ShowCover(*song);
 }
 
-void EditTagDialog::UpdateCoverOf(const Song& selected, const QModelIndexList& sel,
+void EditTagDialog::UpdateCoverOf(const Song& selected,
+                                  const QModelIndexList& sel,
                                   const QString& cover) {
-  if (!selected.is_valid() || selected.id() == -1)
-    return;
+  if (!selected.is_valid() || selected.id() == -1) return;
 
   UpdateSummaryTab(selected);
 
   // Now check if we have any other songs cached that share that artist and
   // album (and would therefore be changed as well)
-  for (int i=0 ; i<data_.count() ; ++i) {
-    if (i == sel.first().row()) // Already changed this one
+  for (int i = 0; i < data_.count(); ++i) {
+    if (i == sel.first().row())  // Already changed this one
       continue;
 
     Song* other_song = &data_[i].original_;
     if (selected.artist() == other_song->artist() &&
-        selected.album()  == other_song->album()) {
+        selected.album() == other_song->album()) {
       other_song->set_art_manual(cover);
     }
   }
@@ -642,7 +674,8 @@ void EditTagDialog::PreviousSong() {
     return;
   }
 
-  int row = (ui_->song_list->currentRow() - 1 + ui_->song_list->count()) % ui_->song_list->count();
+  int row = (ui_->song_list->currentRow() - 1 + ui_->song_list->count()) %
+            ui_->song_list->count();
   ui_->song_list->setCurrentRow(row);
 }
 
@@ -653,38 +686,30 @@ void EditTagDialog::ButtonClicked(QAbstractButton* button) {
 }
 
 void EditTagDialog::SaveData(const QList<Data>& data) {
-  for (int i=0 ; i<data.count() ; ++i) {
+  for (int i = 0; i < data.count(); ++i) {
     const Data& ref = data[i];
-    if (ref.current_.IsMetadataEqual(ref.original_))
-      continue;
+    if (ref.current_.IsMetadataEqual(ref.original_)) continue;
 
     if (!TagReaderClient::Instance()->SaveFileBlocking(
-          ref.current_.url().toLocalFile(), ref.current_)) {
-      emit Error(tr("An error occurred writing metadata to '%1'").arg(ref.current_.url().toLocalFile()));
+            ref.current_.url().toLocalFile(), ref.current_)) {
+      emit Error(tr("An error occurred writing metadata to '%1'")
+                     .arg(ref.current_.url().toLocalFile()));
     }
   }
 }
 
 void EditTagDialog::accept() {
   // Show the loading indicator
-  if (!SetLoading(tr("Saving tracks") + "..."))
-    return;
+  if (!SetLoading(tr("Saving tracks") + "...")) return;
 
   // Save tags in the background
-  QFuture<void> future = QtConcurrent::run(this, &EditTagDialog::SaveData, data_);
-  QFutureWatcher<void>* watcher = new QFutureWatcher<void>(this);
-  watcher->setFuture(future);
-  connect(watcher, SIGNAL(finished()), SLOT(AcceptFinished()));
+  QFuture<void> future =
+      QtConcurrent::run(this, &EditTagDialog::SaveData, data_);
+  NewClosure(future, this, SLOT(AcceptFinished()));
 }
 
 void EditTagDialog::AcceptFinished() {
-  QFutureWatcher<void>* watcher = dynamic_cast<QFutureWatcher<void>*>(sender());
-  if (!watcher)
-    return;
-  watcher->deleteLater();
-
-  if (!SetLoading(QString()))
-    return;
+  if (!SetLoading(QString())) return;
 
   QDialog::accept();
 }
@@ -706,10 +731,12 @@ bool EditTagDialog::eventFilter(QObject* o, QEvent* e) {
 
       case QEvent::Drop: {
         const QDropEvent* event = static_cast<QDropEvent*>(e);
-        const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
+        const QModelIndexList sel =
+            ui_->song_list->selectionModel()->selectedIndexes();
         Song* song = GetFirstSelected();
 
-        const QString cover = album_cover_choice_controller_->SaveCover(song, event);
+        const QString cover =
+            album_cover_choice_controller_->SaveCover(song, event);
         if (!cover.isEmpty()) {
           UpdateCoverOf(*song, sel, cover);
         }
@@ -746,28 +773,27 @@ void EditTagDialog::hideEvent(QHideEvent* e) {
 }
 
 void EditTagDialog::SongRated(float rating) {
-  const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
-  if (sel.isEmpty())
-    return;
+  const QModelIndexList sel =
+      ui_->song_list->selectionModel()->selectedIndexes();
+  if (sel.isEmpty()) return;
   Song* song = &data_[sel.first().row()].original_;
-  if (!song->is_valid() || song->id() == -1)
-    return;
+  if (!song->is_valid() || song->id() == -1) return;
 
   song->set_rating(rating);
   app_->library_backend()->UpdateSongRatingAsync(song->id(), rating);
 }
 
 void EditTagDialog::ResetPlayCounts() {
-  const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
-  if (sel.isEmpty())
-    return;
+  const QModelIndexList sel =
+      ui_->song_list->selectionModel()->selectedIndexes();
+  if (sel.isEmpty()) return;
   Song* song = &data_[sel.first().row()].original_;
-  if (!song->is_valid() || song->id() == -1)
-    return;
+  if (!song->is_valid() || song->id() == -1) return;
 
-  if (QMessageBox::question(this, tr("Reset play counts"),
-        tr("Are you sure you want to reset this song's statistics?"),
-        QMessageBox::Reset, QMessageBox::Cancel) != QMessageBox::Reset) {
+  if (QMessageBox::question(
+          this, tr("Reset play counts"),
+          tr("Are you sure you want to reset this song's statistics?"),
+          QMessageBox::Reset, QMessageBox::Cancel) != QMessageBox::Reset) {
     return;
   }
 
@@ -780,11 +806,12 @@ void EditTagDialog::ResetPlayCounts() {
 }
 
 void EditTagDialog::FetchTag() {
-  const QModelIndexList sel = ui_->song_list->selectionModel()->selectedIndexes();
+  const QModelIndexList sel =
+      ui_->song_list->selectionModel()->selectedIndexes();
 
   SongList songs;
 
-  foreach (const QModelIndex& index, sel) {
+  for (const QModelIndex& index : sel) {
     Song song = data_[index.row()].original_;
     if (!song.is_valid()) {
       continue;
@@ -793,8 +820,7 @@ void EditTagDialog::FetchTag() {
     songs << song;
   }
 
-  if (songs.isEmpty())
-    return;
+  if (songs.isEmpty()) return;
 
   results_dialog_->Init(songs);
   tag_fetcher_->StartFetch(songs);
@@ -802,32 +828,32 @@ void EditTagDialog::FetchTag() {
   results_dialog_->show();
 }
 
-void EditTagDialog::FetchTagSongChosen(const Song& original_song, const Song& new_metadata) {
+void EditTagDialog::FetchTagSongChosen(const Song& original_song,
+                                       const Song& new_metadata) {
   const QString filename = original_song.url().toLocalFile();
 
   // Find the song with this filename
-  for (int i=0 ; i<data_.count() ; ++i) {
-    Data* data = &data_[i];
-    if (data->original_.url().toLocalFile() != filename)
-      continue;
+  auto data_it =
+      std::find_if(data_.begin(), data_.end(), [&filename](const Data& d) {
+        return d.original_.url().toLocalFile() == filename;
+      });
+  if (data_it == data_.end()) {
+    qLog(Warning) << "Could not find song to filename: " << filename;
+    return;
+  }
 
-    // Is it currently being displayed in the UI?
-    if (ui_->song_list->currentRow() == i) {
-      // Yes!  We can just set the fields in the UI
-      ui_->title->set_text(new_metadata.title());
-      ui_->artist->set_text(new_metadata.artist());
-      ui_->album->set_text(new_metadata.album());
-      ui_->track->setValue(new_metadata.track());
-      ui_->year->setValue(new_metadata.year());
-    } else {
-      data->current_.set_title(new_metadata.title());
-      data->current_.set_artist(new_metadata.artist());
-      data->current_.set_album(new_metadata.album());
-      data->current_.set_track(new_metadata.track());
-      data->current_.set_year(new_metadata.year());
-    }
+  data_it->current_.set_title(new_metadata.title());
+  data_it->current_.set_artist(new_metadata.artist());
+  data_it->current_.set_album(new_metadata.album());
+  data_it->current_.set_track(new_metadata.track());
+  data_it->current_.set_year(new_metadata.year());
 
-    break;
+  // Is it currently selected in the UI?
+  int row = data_it - data_.begin();
+  if (ui_->song_list->item(row)->isSelected()) {
+    // We need to update view
+    for (const FieldData& field : fields_)
+      InitFieldValue(field,
+                     ui_->song_list->selectionModel()->selectedIndexes());
   }
 }
-
