@@ -21,14 +21,22 @@
 #include <QIcon>
 
 class IconLoader {
-public:
-  static void Init();
-  static QIcon Load(const QString& name);
+ public:
+  enum IconType {
+    Base = 0,
+    Provider = 1,
+    Lastfm = 2
+  };
 
-private:
+  static void Init();
+  static QIcon Load(const QString& name, const IconType& icontype);
+
+ private:
   IconLoader() {}
 
   static QList<int> sizes_;
+  static QString custom_icon_path_;
+  static QList<QString> icon_sub_path_;
 };
 
-#endif // ICONLOADER_H
+#endif  // ICONLOADER_H
